summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/radiobutton.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/radiobutton.h')
-rw-r--r--kalarm/lib/radiobutton.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/kalarm/lib/radiobutton.h b/kalarm/lib/radiobutton.h
index d95d13fa5..9395be608 100644
--- a/kalarm/lib/radiobutton.h
+++ b/kalarm/lib/radiobutton.h
@@ -39,21 +39,22 @@
*
* @author David Jarvie <software@astrojar.org.uk>
*/
-class RadioButton : public QRadioButton
+class RadioButton : public TQRadioButton
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constructor.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit RadioButton(TQWidget* parent, const char* name = 0);
+ explicit RadioButton(TQWidget* tqparent, const char* name = 0);
/** Constructor.
* @param text Text to display.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- RadioButton(const TQString& text, TQWidget* parent, const char* name = 0);
+ RadioButton(const TQString& text, TQWidget* tqparent, const char* name = 0);
/** Returns true if the widget is read only. */
bool isReadOnly() const { return mReadOnly; }
/** Sets whether the radio button is read-only for the user. If read-only,
@@ -79,7 +80,7 @@ class RadioButton : public QRadioButton
protected slots:
void slotClicked();
private:
- TQWidget::FocusPolicy mFocusPolicy; // default focus policy for the QRadioButton
+ TQWidget::FocusPolicy mFocusPolicy; // default focus policy for the TQRadioButton
TQWidget* mFocusWidget; // widget to receive focus when button is clicked on
bool mFocusWidgetEnable; // enable focus widget before setting focus
bool mReadOnly; // value cannot be changed
@@ -39,21 +39,22 @@
public:
/** Constructor.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
@@ -39,21 +39,22 @@
/** Constructor.
* @param text Text to display.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/